##
## 2015 Unemployment Data
##

readLAUS <- function(file = "http://www.stat.uiowa.edu/~luke/data/laus/laucntycur14-2016.txt") {
    fullData <- read.table(file, 
                           col.names = c("LAUSAreaCode",
                                         "State", "County",
                                         "Title", "Period",
                                         "LaborForce", "Employed",
                                         "Unemployed", "UnempRate"),
                           quote = '"', sep = "|", skip = 6,
                           stringsAsFactors = FALSE,
                           strip.white = TRUE,
                           fill = TRUE)
    ## remove footer
    footstart <- grep("------", fullData$LAUSAreaCode)
    fullData <- fullData[1:(footstart - 1),]

    ## separate out state, county names
    fullData$StateCharCode <- sub("^.*, ", "", fullData$Title)
    fullData$CountyName <- sub(", .*", "", fullData$Title)

    ## remove commas from numbers and convert to numeric
    fullData$LaborForce <-
        as.numeric(gsub(",", "", fullData$LaborForce))
    fullData$Employed <-
        as.numeric(gsub(",", "", fullData$Employed))
    fullData$Unemployed <-
        as.numeric(gsub(",", "", fullData$Unemployed))

    fullData
}

laus <- readLAUS()
ilaus <- subset(laus, StateCharCode == "IA")

periods <- unique(ilaus$Period)
UI <- lapply(periods,
             function(p)
                 ilaus$UnempRate[ilaus$Period == p])

library(maps)
library(RColorBrewer)
palette <- brewer.pal(6, "Blues")
